@@ -7,12 +7,10 @@
 
 #include "ibusfrontend.h"
 #include <fcntl.h>
-#include <signal.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#include <fstream>
-#include <mutex>
+#include <csignal>
 #include <fmt/format.h>
 #include "fcitx-config/iniparser.h"
 #include "fcitx-utils/dbus/message.h"
@@ -25,7 +23,9 @@
 #include "fcitx-utils/stringutils.h"
 #include "fcitx-utils/utf8.h"
 #include "fcitx-utils/uuid_p.h"
+#include "fcitx/addonfactory.h"
 #include "fcitx/inputcontext.h"
+#include "fcitx/inputpanel.h"
 #include "fcitx/instance.h"
 #include "fcitx/misc_p.h"
 #include "dbus_public.h"
@@ -89,9 +89,10 @@ std::string getSocketPath(bool isWayland) {
                             hostname, "-", displaynumber));
 }
 
-std::string getFullSocketPath(bool isWayland) {
+std::string getFullSocketPath(const StandardPath &standardPath,
+                              bool isWayland) {
     return stringutils::joinPath(
-        StandardPath::global().userDirectory(StandardPath::Type::Config),
+        standardPath.userDirectory(StandardPath::Type::Config),
         getSocketPath(isWayland));
 }
 
@@ -130,8 +131,8 @@ std::pair<std::string, pid_t> getAddress(const std::string &socketPath) {
 }
 
 pid_t runIBusExit() {
-    pid_t child_pid;
-    if ((child_pid = fork()) == -1) {
+    pid_t child_pid = fork();
+    if (child_pid == -1) {
         perror("fork");
         return -1;
     }
@@ -248,7 +249,7 @@ public:
         created();
     }
 
-    ~IBusInputContext() { InputContext::destroy(); }
+    ~IBusInputContext() override { InputContext::destroy(); }
 
     const char *frontend() const override { return "ibus"; }
 
@@ -407,8 +408,11 @@ public:
     void enable() {}
     void disable() {}
     static bool isEnabled() { return true; }
-    void propertyActivate(const std::string &, int32_t) {}
-    void setEngine(const std::string &) {}
+    void propertyActivate(const std::string &name, int32_t state) {
+        FCITX_UNUSED(name);
+        FCITX_UNUSED(state);
+    }
+    void setEngine(const std::string &engine) { FCITX_UNUSED(engine); }
     static dbus::Variant getEngine() { return dbus::Variant(0); }
     void setSurroundingText(const dbus::Variant &text, uint32_t cursor,
                             uint32_t anchor) {
@@ -509,7 +513,7 @@ private:
 
 #define CASE_PURPOSE(_PURPOSE, _CAPABILITY)                                    \
     case _PURPOSE:                                                             \
-        flag |= _CAPABILITY;                                                   \
+        flag |= (_CAPABILITY);                                                 \
         break;
 
         switch (purpose) {
@@ -545,8 +549,8 @@ private:
         };
 
 #define CHECK_HINTS(_HINTS, _CAPABILITY)                                       \
-    if (hints & _HINTS) {                                                      \
-        flag |= _CAPABILITY;                                                   \
+    if (hints & (_HINTS)) {                                                    \
+        flag |= (_CAPABILITY);                                                 \
     }
 
         CHECK_HINTS(GTK_INPUT_HINT_SPELLCHECK,
@@ -625,12 +629,12 @@ IBusFrontend::createInputContext(const std::string & /* unused */) {
     return ic->path();
 }
 
-std::set<std::string> allSocketPaths() {
+std::set<std::string> allSocketPaths(const StandardPath &standardPath) {
     std::set<std::string> paths;
     if (isInFlatpak()) {
         // Flatpak always use DISPLAY=:99, which means we will need to guess
         // what files are available.
-        auto map = StandardPath::global().multiOpenFilter(
+        auto map = standardPath.multiOpenFilter(
             StandardPath::Type::Config, "ibus/bus", O_RDONLY,
             [](const std::string &path, const std::string &, bool user) {
                 if (!user) {
@@ -646,8 +650,8 @@ std::set<std::string> allSocketPaths() {
         // Make the guess that display is 0, it is the most common value that
         // people would have.
         if (paths.empty()) {
-            auto configHome = StandardPath::global().userDirectory(
-                StandardPath::Type::Config);
+            auto configHome =
+                standardPath.userDirectory(StandardPath::Type::Config);
             if (!configHome.empty()) {
                 paths.insert(stringutils::joinPath(
                     configHome, "ibus/bus",
@@ -655,20 +659,20 @@ std::set<std::string> allSocketPaths() {
             }
         }
     } else {
-        if (auto path = getFullSocketPath(false); !path.empty()) {
+        if (auto path = getFullSocketPath(standardPath, false); !path.empty()) {
             paths.insert(std::move(path));
         }
     }
 
     // Also add wayland.
-    if (auto path = getFullSocketPath(true); !path.empty()) {
+    if (auto path = getFullSocketPath(standardPath, true); !path.empty()) {
         paths.insert(std::move(path));
     }
     return paths;
 }
 
 IBusFrontendModule::IBusFrontendModule(Instance *instance)
-    : instance_(instance), socketPaths_(allSocketPaths()) {
+    : instance_(instance), socketPaths_(allSocketPaths(standardPath_)) {
     dbus::VariantTypeRegistry::defaultRegistry().registerType<IBusText>();
     dbus::VariantTypeRegistry::defaultRegistry().registerType<IBusAttribute>();
     dbus::VariantTypeRegistry::defaultRegistry().registerType<IBusAttrList>();
@@ -718,17 +722,17 @@ IBusFrontendModule::~IBusFrontendModule() {
         portalBus_->releaseName(IBUS_PORTAL_DBUS_SERVICE);
     }
 
-    if (addressWrote_.empty()) {
+    if (addressWrote_.empty() || socketPaths_.empty()) {
         return;
     }
+    // Writeback an empty invalid address file.
+    RawConfig config;
+    config.setValueByPath("IBUS_ADDRESS", "");
+    config.setValueByPath("IBUS_DAEMON_PID", "");
     for (const auto &path : socketPaths_) {
         auto address = getAddress(path);
         if (address.first == addressWrote_ && address.second == pidWrote_) {
-            // Writeback an empty invalid address file.
-            RawConfig config;
-            config.setValueByPath("IBUS_ADDRESS", "");
-            config.setValueByPath("IBUS_DAEMON_PID", "");
-            StandardPath::global().safeSave(
+            standardPath_.safeSave(
                 StandardPath::Type::Config, path,
                 [&config](int fd) { return writeAsIni(config, fd); });
         }
@@ -818,13 +822,13 @@ void IBusFrontendModule::replaceIBus(bool recheck) {
             return;
         }
     } else if (auto optionalAddress = readIBusInfo(socketPaths_)) {
-        auto address = *optionalAddress;
         auto pid = runIBusExit();
         if (pid > 0) {
             FCITX_IBUS_DEBUG() << "Running ibus exit.";
             timeEvent_ = instance()->eventLoop().addTimeEvent(
                 CLOCK_MONOTONIC, now(CLOCK_MONOTONIC) + 1000000, 0,
-                [this, pid, address, recheck](EventSourceTime *, uint64_t) {
+                [this, pid, address = std::move(*optionalAddress),
+                 recheck](EventSourceTime *, uint64_t) {
                     int stat = -1;
                     pid_t ret;
                     while ((ret = waitpid(pid, &stat, WNOHANG)) <= 0) {
@@ -880,10 +884,9 @@ void IBusFrontendModule::becomeIBus(bool recheck) {
     auto address = bus()->address();
     if (isInFlatpak()) {
         if (address.find("/run/flatpak/bus") != std::string::npos) {
-            auto userBus =
-                stringutils::joinPath(StandardPath::global().userDirectory(
-                                          StandardPath::Type::Runtime),
-                                      "bus");
+            auto userBus = stringutils::joinPath(
+                standardPath_.userDirectory(StandardPath::Type::Runtime),
+                "bus");
 
             struct stat statbuf;
 
@@ -918,14 +921,14 @@ void IBusFrontendModule::becomeIBus(bool recheck) {
 
     FCITX_IBUS_DEBUG() << "Writing ibus daemon info.";
     for (const auto &path : socketPaths_) {
-        if (!StandardPath::global().safeSave(
+        if (!standardPath_.safeSave(
                 StandardPath::Type::Config, path,
                 [&config](int fd) { return writeAsIni(config, fd); })) {
             return;
         }
     }
 
-    addressWrote_ = address;
+    addressWrote_ = std::move(address);
     pidWrote_ = pidToWrite;
 
     if (!recheck) {
