@@ -25,6 +25,7 @@
 #include "fcitx-utils/stringutils.h"
 #include "fcitx-utils/utf8.h"
 #include "fcitx/event.h"
+#include "fcitx/inputmethodgroup.h"
 #include "../../modules/notifications/notifications_public.h"
 #include "addonmanager.h"
 #include "focusgroup.h"
@@ -40,6 +41,7 @@
 #include "userinterfacemanager.h"
 
 #ifdef ENABLE_X11
+#define FCITX_NO_XCB
 #include <../modules/xcb/xcb_public.h>
 #endif
 
@@ -139,7 +141,7 @@ void InstanceArgument::printUsage() const {
            "disconnected.\n"
         << "  -r, --replace\t\t\tReplace the existing instance.\n"
         << "  -o --option <option>\t\tPass the option to addons\n"
-        << "\t\t\t\t<option> is in format like:"
+        << "\t\t\t\t<option> is in format like:\n"
         << "\t\t\t\tname1=opt1a:opt1b,name2=opt2a:opt2b... .\n"
         << "  -v, --version\t\t\tShow version and quit.\n"
         << "  -h, --help\t\t\tShow this help message and quit.\n";
@@ -399,9 +401,9 @@ void InstancePrivate::showInputMethodInformation(InputContext *ic) {
                         : entry->name();
         if (globalConfig_.compactInputMethodInformation() &&
             !subModeLabel.empty()) {
-            display = subModeLabel;
+            display = std::move(subModeLabel);
         } else if (subMode.empty()) {
-            display = name;
+            display = std::move(name);
         } else {
             display = fmt::format(_("{0} ({1})"), name, subMode);
         }
@@ -500,13 +502,13 @@ void InputState::showInputMethodInformation(const std::string &name) {
 #ifdef ENABLE_KEYBOARD
 xkb_state *InputState::customXkbState(bool refresh) {
     auto *instance = d_ptr->q_func();
-    auto defaultLayout = d_ptr->imManager_.currentGroup().defaultLayout();
-    auto im = instance->inputMethod(ic_);
-    auto layout = d_ptr->imManager_.currentGroup().layoutFor(im);
+    const InputMethodGroup &group = d_ptr->imManager_.currentGroup();
+    const auto im = instance->inputMethod(ic_);
+    auto layout = group.layoutFor(im);
     if (layout.empty() && stringutils::startsWith(im, "keyboard-")) {
         layout = im.substr(9);
     }
-    if (layout == defaultLayout || layout.empty()) {
+    if (layout.empty() || layout == group.defaultLayout()) {
         // Use system one.
         xkbState_.reset();
         modsAllReleased_ = false;
@@ -519,7 +521,7 @@ xkb_state *InputState::customXkbState(bool refresh) {
     }
 
     lastXkbLayout_ = layout;
-    auto layoutAndVariant = parseLayout(layout);
+    const auto layoutAndVariant = parseLayout(layout);
     if (auto *keymap = d_ptr->keymap(ic_->display(), layoutAndVariant.first,
                                      layoutAndVariant.second)) {
         xkbState_.reset(xkb_state_new(keymap));
@@ -1626,8 +1628,8 @@ std::string Instance::inputMethod(InputContext *ic) {
     if (ic->capabilityFlags().test(CapabilityFlag::Disable) ||
         (ic->capabilityFlags().test(CapabilityFlag::Password) &&
          !d->globalConfig_.allowInputMethodForPassword())) {
-        auto defaultLayout = group.defaultLayout();
-        auto defaultLayoutIM = stringutils::concat("keyboard-", defaultLayout);
+        auto defaultLayoutIM =
+            stringutils::concat("keyboard-", group.defaultLayout());
         const auto *entry = d->imManager_.entry(defaultLayoutIM);
         if (!entry) {
             entry = d->imManager_.entry("keyboard-us");
@@ -1679,16 +1681,18 @@ InputMethodEngine *Instance::inputMethodEngine(const std::string &name) {
 }
 
 std::string Instance::inputMethodIcon(InputContext *ic) {
-    std::string icon = "input-keyboard";
-
+    std::string icon;
     const auto *entry = inputMethodEntry(ic);
-    auto *engine = inputMethodEngine(ic);
-
-    if (engine) {
-        icon = engine->subModeIcon(*entry, *ic);
-    }
-    if (icon.empty()) {
-        icon = entry->icon();
+    if (entry) {
+        auto *engine = inputMethodEngine(ic);
+        if (engine) {
+            icon = engine->subModeIcon(*entry, *ic);
+        }
+        if (icon.empty()) {
+            icon = entry->icon();
+        }
+    } else {
+        icon = "input-keyboard";
     }
     return icon;
 }
@@ -2267,7 +2271,7 @@ Text Instance::outputFilter(InputContext *inputContext, const Text &orig) {
                 dot += "\xe2\x80\xa2";
                 length -= 1;
             }
-            newText.append(dot,
+            newText.append(std::move(dot),
                            result.formatAt(i) | TextFormatFlag::DontCommit);
         }
         result = std::move(newText);
