@@ -14,7 +14,6 @@
 #include <stdexcept>
 #include <string>
 #include <gio/gio.h>
-#include <wayland-client.h>
 #include "fcitx-config/iniparser.h"
 #include "fcitx-utils/event.h"
 #include "fcitx-utils/log.h"
@@ -283,11 +282,11 @@ bool WaylandModule::reopenConnectionSocket(const std::string &displayName,
     std::string name = displayName;
 
     auto iter = conns_.find(name);
-    if (iter == conns_.end() && !name.empty()) {
+    if (iter == conns_.end()) {
         do {
             // If it's in flatpak, WAYLAND_DISPLAY may be overrrided, so don't
             // compare it with default connection.
-            if (!isInFlatpak()) {
+            if (!isInFlatpak() && !name.empty()) {
                 iter = conns_.find("");
                 if (iter != conns_.end() && iter->second->realName() == name) {
                     name = "";
@@ -335,7 +334,7 @@ bool WaylandModule::reopenConnectionSocket(const std::string &displayName,
         onConnectionCreated(*iter->second);
         // Transfer it to new connection's IC group, we do create two focus
         // group with same name, but well, ic manager doesn't check that.
-        for (auto icRef : ics) {
+        for (const auto &icRef : ics) {
             if (auto ic = icRef.get()) {
                 if (!ic->focusGroup()) {
                     ic->setFocusGroup(iter->second->focusGroup());
@@ -549,7 +548,8 @@ void WaylandModule::selfDiagnose() {
 
     bool isWaylandIM = false;
     if (isInFlatpak()) {
-        // In flatpak, ReopenWaylandConnection will not replace existing connection.
+        // In flatpak, ReopenWaylandConnection will not replace existing
+        // connection.
         for (const auto &[_, conn] : conns_) {
             conn->focusGroup()->foreach([&isWaylandIM](InputContext *ic) {
                 if (stringutils::startsWith(ic->frontendName(), "wayland")) {
