@@ -5,13 +5,10 @@
  *
  */
 
-#include <fcntl.h>
 #include <locale.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <exception>
 #include <iostream>
-#include <libintl.h>
 #include "fcitx-utils/fs.h"
 #include "fcitx-utils/misc.h"
 #include "fcitx-utils/misc_p.h"
@@ -86,12 +83,14 @@ int main(int argc, char *argv[]) {
     }
 
     if (restart && canRestart) {
-        auto fcitxBinary = StandardPath::fcitxPath("bindir", "fcitx5");
+        std::vector<std::string> args;
         if (isInFlatpak()) {
-            startProcess({"flatpak-spawn", fcitxBinary, "-rd"});
+            args = {"flatpak-spawn",
+                    StandardPath::fcitxPath("bindir", "fcitx5"), "-rd"};
         } else {
-            startProcess({fcitxBinary, "-r"});
+            args = {StandardPath::fcitxPath("bindir", "fcitx5"), "-r"};
         }
+        startProcess(args);
     }
     return ret;
 }
